pub struct TripletLoss {
pub axis: i32,
pub p: f32,
pub margin: f32,
pub eps: f32,
pub reduction: LossReduction,
}Expand description
Computes the triplet loss for a set of anchor, positive, and negative samples. Margin is represented with alpha in the math section.
Fields
axis: i32Distribution axis. Default to TripletLoss::DEFAULT_AXIS
p: f32The norm degree for pairwise distance. Default to TripletLoss::DEFAULT_P
margin: f32Margin for the triplet loss. Default to TripletLoss::DEFAULT_MARGIN
eps: f32Small positive constant for numerical stability. Default to TripletLoss::DEFAULT_EPS
reduction: LossReductionReduction type. Default to TripletLoss::DEFAULT_REDUCTION
Implementations
Sourceimpl TripletLoss
impl TripletLoss
Sourceimpl TripletLoss
impl TripletLoss
Sourcepub const DEFAULT_AXIS: i32 = -1
pub const DEFAULT_AXIS: i32 = -1
Default value for the axis parameter.
Sourcepub const DEFAULT_MARGIN: f32 = 1.0
pub const DEFAULT_MARGIN: f32 = 1.0
Default value for the margin parameter.
Sourcepub const DEFAULT_EPS: f32 = 1e-6
pub const DEFAULT_EPS: f32 = 1e-6
Default value for the eps parameter.
Sourcepub const DEFAULT_REDUCTION: LossReduction = LossReduction::None
pub const DEFAULT_REDUCTION: LossReduction = LossReduction::None
Default value for the reduction parameter.
Sourcepub fn apply(
&self,
anchors: impl AsRef<Array>,
positives: impl AsRef<Array>,
negatives: impl AsRef<Array>,
) -> Result<Array, Exception>
pub fn apply( &self, anchors: impl AsRef<Array>, positives: impl AsRef<Array>, negatives: impl AsRef<Array>, ) -> Result<Array, Exception>
Computes the triplet loss for a set of anchor, positive, and negative samples. Margin is represented with alpha in the math section.
Params
anchors: The anchor samplespositives: The positive samplesneonatives: The negative samples